/*
* *********************************************************************************************************************
*
*          !!
*        .F88X
*        X8888Y
*      .}888888N;
*        i888888N;        .:!              .I$WI:
*          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
*          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
*            +888888N;  .8888888Y                                  "&&8Y.}8,
*            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
*              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
*              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
*            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
*            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
*          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
*        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
*      .:R888888I
*      .&888888I                                          Copyright (c) 2016-2020.  博锐尚格科技股份有限公司
*        ~8888'
*        .!88~                                                                     All rights reserved.
*
* *********************************************************************************************************************
*/

import { SBaseTextEdit } from "@persagy-web/edit";
import { SGraphItem } from "@persagy-web/graph/lib";
import { SColor, SPainter } from '@persagy-web/draw/lib';
import { Marker } from "@persagy-web/big/lib";

/**
  * 编辑基础按钮类
  *
  * @author 韩耀龙 <han_yao_long@163.com>
  */

export class SBaseBtns extends SBaseTextEdit {

    /**
    * 构造函数
    *
    * @param parent      指向父 Item
    * @param str         文本内容
    */
    constructor(parent: SGraphItem | null, data: Marker) {
        super(parent, data);
        this.lineWidth = data.style.default.lineWidth;
        this.strokeColor = new SColor(data.style.default.strokeColor);
        this.backgroundColor = new SColor(data.style.default.backgroundColor);
        this.isTransform = true;
    }

    /**
    * 绘制显示状态文本 Item
    *
    * @param painter    绘制类
    */
    protected drawShowText(painter: SPainter): void {
        painter.translate(-this.origin.x, -this.origin.y);
        //绘制矩形轮廓，是否选中
        if (this.selected) {
            painter.shadow.shadowBlur = 10;
            painter.shadow.shadowColor = new SColor(`#00000033`);
            painter.shadow.shadowOffsetX = 5;
            painter.shadow.shadowOffsetY = 5;
        } else {
            painter.shadow.shadowColor = SColor.Transparent;
        }

        //绘制文本
        painter.brush.color = new SColor(this.color);
        painter.pen.color = new SColor(this.color);
        painter.shadow.shadowColor = SColor.Transparent;
        painter.font = this.font;
        painter.drawText(
            this.text,
            this.font.size / 4,
            this.font.size / 4,
            this.maxWidth
        );

        // painter.brush.color = this.backgroundColor;
        // painter.pen.lineWidth = this.lineWidth;
        // painter.pen.color = this.strokeColor;
        // painter.drawRect(0, 0, this.width, this.height);
    }

    /**
    * Item 绘制操作
    *
    * @param painter   绘画对象
    */
    onDraw(painter: SPainter): void {
        super.onDraw(painter)
        painter.brush.color = this.backgroundColor;
        painter.pen.lineWidth = this.lineWidth;
        painter.pen.color = this.strokeColor;
        painter.drawRect(0, 0, this.width, this.height);
    }

}